@@ -122,6 +122,12 @@
 #include <stdlib.h>
 #include "libconfig.h"
 #ifdef WIN32
+
+// prevent warnings about redefined malloc/free in generated code:
+#ifndef _STDLIB_H
+#define _STDLIB_H
+#endif
+  
 #include <malloc.h>
 #endif
 #include "private.h"
@@ -129,7 +135,6 @@
 //these delcarations are provided to suppress compiler warnings
 extern int libconfig_yylex();
 extern int libconfig_yyget_lineno();
-
   
 static const char *err_array_elem_type = "mismatched element type in array";
 static const char *err_duplicate_setting = "duplicate setting name";
@@ -140,6 +145,9 @@ static const char *err_duplicate_setting = "duplicate setting name";
 #define IN_LIST() \
   (ctx->parent && (ctx->parent->type == CONFIG_TYPE_LIST))
 
+#define CAPTURE_PARSE_POS(S)                                    \
+  (S)->line = (unsigned int)libconfig_yyget_lineno(scanner)
+
 void libconfig_yyerror(void *scanner, struct parse_context *ctx,
                       char const *s)
 {
@@ -170,14 +178,14 @@ void libconfig_yyerror(void *scanner, struct parse_context *ctx,
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 65 "grammar.y"
+#line 73 "grammar.y"
 {
   long ival;
   double fval;
   char *sval;
 }
 /* Line 193 of yacc.c.  */
-#line 181 "grammar.c"
+#line 189 "grammar.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -190,7 +198,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 194 "grammar.c"
+#line 202 "grammar.c"
 
 #ifdef short
 # undef short
@@ -483,10 +491,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    78,    78,    80,    84,    85,    88,    90,    95,    94,
-     111,   110,   131,   130,   152,   153,   154,   155,   159,   172,
-     191,   210,   223,   245,   246,   249,   251,   255,   256,   259,
-     261,   266,   265
+       0,    86,    86,    88,    92,    93,    96,    98,   103,   102,
+     123,   122,   146,   145,   168,   169,   170,   171,   175,   195,
+     217,   239,   257,   284,   285,   288,   290,   294,   295,   298,
+     300,   305,   304
 };
 #endif
 
@@ -1429,7 +1437,7 @@ yyreduce:
   switch (yyn)
     {
         case 8:
-#line 95 "grammar.y"
+#line 103 "grammar.y"
     {
     ctx->setting = config_setting_add(ctx->parent, (yyvsp[(1) - (1)].sval), CONFIG_TYPE_NONE);
     free((yyvsp[(1) - (1)].sval));
@@ -1439,14 +1447,21 @@ yyreduce:
       libconfig_yyerror(scanner, ctx, err_duplicate_setting);
       YYABORT;
     }
+    else
+    {
+      CAPTURE_PARSE_POS(ctx->setting);
+    }
   }
     break;
 
   case 10:
-#line 111 "grammar.y"
+#line 123 "grammar.y"
     {
     if(IN_LIST())
+    {
       ctx->parent = config_setting_add(ctx->parent, NULL, CONFIG_TYPE_ARRAY);
+      CAPTURE_PARSE_POS(ctx->parent);
+    }
     else
     {
       ctx->setting->type = CONFIG_TYPE_ARRAY;
@@ -1457,7 +1472,7 @@ yyreduce:
     break;
 
   case 11:
-#line 123 "grammar.y"
+#line 138 "grammar.y"
     {
     if(ctx->parent)
       ctx->parent = ctx->parent->parent;    
@@ -1465,11 +1480,12 @@ yyreduce:
     break;
 
   case 12:
-#line 131 "grammar.y"
+#line 146 "grammar.y"
     {
     if(IN_LIST())
     {
       ctx->parent = config_setting_add(ctx->parent, NULL, CONFIG_TYPE_LIST);
+      CAPTURE_PARSE_POS(ctx->parent);
     }
     else
     {
@@ -1481,7 +1497,7 @@ yyreduce:
     break;
 
   case 13:
-#line 145 "grammar.y"
+#line 161 "grammar.y"
     {
     if(ctx->parent)
       ctx->parent = ctx->parent->parent;    
@@ -1489,15 +1505,22 @@ yyreduce:
     break;
 
   case 18:
-#line 160 "grammar.y"
+#line 176 "grammar.y"
     {
     if(IN_ARRAY() || IN_LIST())
     {
-      if(! config_setting_set_bool_elem(ctx->parent, -1, (int)(yyvsp[(1) - (1)].ival)))
+      config_setting_t *e = config_setting_set_bool_elem(ctx->parent, -1,
+                                                         (int)(yyvsp[(1) - (1)].ival));
+      
+      if(! e)
       {
         libconfig_yyerror(scanner, ctx, err_array_elem_type);
         YYABORT;
       }
+      else
+      {
+        CAPTURE_PARSE_POS(e);
+      }
     }
     else
       config_setting_set_bool(ctx->setting, (int)(yyvsp[(1) - (1)].ival));
@@ -1505,7 +1528,7 @@ yyreduce:
     break;
 
   case 19:
-#line 173 "grammar.y"
+#line 196 "grammar.y"
     {
     if(IN_ARRAY() || IN_LIST())
     {
@@ -1516,7 +1539,10 @@ yyreduce:
         YYABORT;
       }
       else
+      {
         config_setting_set_format(e, CONFIG_FORMAT_DEFAULT);
+        CAPTURE_PARSE_POS(e);
+      }
     }
     else
     {
@@ -1527,7 +1553,7 @@ yyreduce:
     break;
 
   case 20:
-#line 192 "grammar.y"
+#line 218 "grammar.y"
     {
     if(IN_ARRAY() || IN_LIST())
     {
@@ -1538,7 +1564,10 @@ yyreduce:
         YYABORT;
       }
       else
+      {
         config_setting_set_format(e, CONFIG_FORMAT_HEX);
+        CAPTURE_PARSE_POS(e);
+      }
     }
     else
     {
@@ -1549,15 +1578,20 @@ yyreduce:
     break;
 
   case 21:
-#line 211 "grammar.y"
+#line 240 "grammar.y"
     {
     if(IN_ARRAY() || IN_LIST())
     {
-      if(! config_setting_set_float_elem(ctx->parent, -1, (yyvsp[(1) - (1)].fval)))
+      config_setting_t *e = config_setting_set_float_elem(ctx->parent, -1, (yyvsp[(1) - (1)].fval));
+      if(! e)
       {
         libconfig_yyerror(scanner, ctx, err_array_elem_type);
         YYABORT;
       }
+      else
+      {
+        CAPTURE_PARSE_POS(e);
+      }
     }
     else
       config_setting_set_float(ctx->setting, (yyvsp[(1) - (1)].fval));
@@ -1565,18 +1599,23 @@ yyreduce:
     break;
 
   case 22:
-#line 224 "grammar.y"
+#line 258 "grammar.y"
     {
     if(IN_ARRAY() || IN_LIST())
     {
-      if(! config_setting_set_string_elem(ctx->parent, -1, (yyvsp[(1) - (1)].sval)))
+      config_setting_t *e = config_setting_set_string_elem(ctx->parent, -1,
+                                                           (yyvsp[(1) - (1)].sval));
+      free((yyvsp[(1) - (1)].sval));
+      
+      if(! e)
       {
-        free((yyvsp[(1) - (1)].sval));
         libconfig_yyerror(scanner, ctx, err_array_elem_type);
         YYABORT;
       }
       else
-        free((yyvsp[(1) - (1)].sval));
+      {
+        CAPTURE_PARSE_POS(e);
+      }
     }
     else
     {
@@ -1587,10 +1626,13 @@ yyreduce:
     break;
 
   case 31:
-#line 266 "grammar.y"
+#line 305 "grammar.y"
     {
     if(IN_LIST())
+    {
       ctx->parent = config_setting_add(ctx->parent, NULL, CONFIG_TYPE_GROUP);
+      CAPTURE_PARSE_POS(ctx->parent);
+    }
     else
     {
       ctx->setting->type = CONFIG_TYPE_GROUP;
@@ -1601,7 +1643,7 @@ yyreduce:
     break;
 
   case 32:
-#line 278 "grammar.y"
+#line 320 "grammar.y"
     {
     if(ctx->parent)
       ctx->parent = ctx->parent->parent;
@@ -1610,7 +1652,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1614 "grammar.c"
+#line 1656 "grammar.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1824,6 +1866,6 @@ yyreturn:
 }
 
 
-#line 284 "grammar.y"
+#line 326 "grammar.y"
 
 
