@@ -39,7 +39,7 @@
 #define PATH_TOKENS ":./"
 #define CHUNK_SIZE 10
 
-#define _new(T) (T *)calloc(sizeof(T), 1) // zeroed
+#define _new(T) (T *)calloc(sizeof(T), 1) /* zeroed */
 #define _delete(P) free((void *)(P))
 
 // ---------------------------------------------------------------------------
@@ -124,7 +124,7 @@ static void __config_write_value(const config_value_t *value, int type,
 {
   switch(type)
   {
-    // boolean
+    /* boolean */
     case CONFIG_TYPE_BOOL:
       fputs(value->bval ? "true" : "false", stream);
       break;
@@ -143,12 +143,12 @@ static void __config_write_value(const config_value_t *value, int type,
       }
       break;
       
-      // float
+      /* float */
     case CONFIG_TYPE_FLOAT:
       fprintf(stream, "%e", value->fval);
       break;
-
-      // string
+      
+      /* string */
     case CONFIG_TYPE_STRING:
     {
       char *p;
@@ -192,7 +192,7 @@ static void __config_write_value(const config_value_t *value, int type,
       break;
     }
       
-    // list
+    /* list */
     case CONFIG_TYPE_LIST:
     {
       config_list_t *list = value->list;
@@ -220,7 +220,7 @@ static void __config_write_value(const config_value_t *value, int type,
       break;
     }
 
-    // array
+    /* array */
     case CONFIG_TYPE_ARRAY:
     {
       config_list_t *list = value->list;
@@ -248,7 +248,7 @@ static void __config_write_value(const config_value_t *value, int type,
       break;
     }
 
-    // group
+    /* group */
     case CONFIG_TYPE_GROUP:
     {
       config_list_t *list = value->list;
@@ -281,7 +281,7 @@ static void __config_write_value(const config_value_t *value, int type,
     }
 
     default:
-      // this shouldn't happen, but handle it gracefully...
+      /* this shouldn't happen, but handle it gracefully... */
       fputs("???", stream);
       break;
   }
@@ -346,7 +346,7 @@ static void __config_list_remove(config_list_t *list, int index)
 
   if((list->capacity - list->length) >= CHUNK_SIZE)
   {
-    // realloc smaller?
+    /* realloc smaller? */
   }
 }
 
@@ -402,7 +402,7 @@ static void __config_list_destroy(config_list_t *list)
 
 static int __config_vector_checktype(const config_setting_t *vector, int type)
 {
-  // if the array is empty, then it has no type yet
+  /* if the array is empty, then it has no type yet */
   
   if(! vector->value.list)
     return(CONFIG_TRUE);
@@ -410,12 +410,12 @@ static int __config_vector_checktype(const config_setting_t *vector, int type)
   if(vector->value.list->length == 0)
     return(CONFIG_TRUE);
 
-  // if it's a list, any type is allowed
+  /* if it's a list, any type is allowed */
 
   if(vector->type == CONFIG_TYPE_LIST)
     return(CONFIG_TRUE);
   
-  // otherwise the first element added determines the type of the array
+  /* otherwise the first element added determines the type of the array */
   
   return((vector->value.list->elements[0]->type == type)
          ? CONFIG_TRUE : CONFIG_FALSE);
@@ -423,13 +423,13 @@ static int __config_vector_checktype(const config_setting_t *vector, int type)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_read(config_t *config, FILE *stream)
+int config_read(config_t *config, FILE *stream)
 {
   yyscan_t scanner;
   struct parse_context ctx;
   int r;
   
-  // Reinitialize the config (keep the destructor)
+  /* Reinitialize the config (keep the destructor) */
   void (*destructor)(void *) = config->destructor;
   config_destroy(config);
   config_init(config);
@@ -473,14 +473,14 @@ static void __config_write_setting(const config_setting_t *setting,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API void config_write(const config_t *config, FILE *stream)
+void config_write(const config_t *config, FILE *stream)
 {
   __config_write_setting(config->root, stream, 0);
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_read_file(config_t *config, const char *filename)
+int config_read_file(config_t *config, const char *filename)
 {
   int ret;
   FILE *f = fopen(filename, "rt");
@@ -497,7 +497,7 @@ LIBCONFIG_API int config_read_file(config_t *config, const char *filename)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_write_file(config_t *config, const char *filename)
+int config_write_file(config_t *config, const char *filename)
 {
   FILE *f = fopen(filename, "wt");
   if(! f)
@@ -513,7 +513,7 @@ LIBCONFIG_API int config_write_file(config_t *config, const char *filename)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API void config_destroy(config_t *config)
+void config_destroy(config_t *config)
 {
   __config_setting_destroy(config->root);
 
@@ -522,7 +522,7 @@ LIBCONFIG_API void config_destroy(config_t *config)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API void config_init(config_t *config)
+void config_init(config_t *config)
 {
   memset((void *)config, 0, sizeof(config_t));
 
@@ -533,7 +533,7 @@ LIBCONFIG_API void config_init(config_t *config)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API void config_set_auto_convert(config_t *config, int flag)
+void config_set_auto_convert(config_t *config, int flag)
 {
   if(flag)
     config->flags |= CONFIG_OPTION_AUTOCONVERT;
@@ -543,7 +543,7 @@ LIBCONFIG_API void config_set_auto_convert(config_t *config, int flag)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_get_auto_convert(const config_t *config)
+int config_get_auto_convert(const config_t *config)
 {
   return((config->flags & CONFIG_OPTION_AUTOCONVERT) != 0);
 }
@@ -581,7 +581,7 @@ static config_setting_t *config_setting_create(config_setting_t *parent,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API long config_setting_get_int(const config_setting_t *setting)
+long config_setting_get_int(const config_setting_t *setting)
 {
   switch(setting->type)
   {
@@ -601,7 +601,7 @@ LIBCONFIG_API long config_setting_get_int(const config_setting_t *setting)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_set_int(config_setting_t *setting, long value)
+int config_setting_set_int(config_setting_t *setting, long value)
 {
   switch(setting->type)
   {
@@ -629,7 +629,7 @@ LIBCONFIG_API int config_setting_set_int(config_setting_t *setting, long value)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API double config_setting_get_float(const config_setting_t *setting)
+double config_setting_get_float(const config_setting_t *setting)
 {
   switch(setting->type)
   {
@@ -649,8 +649,7 @@ LIBCONFIG_API double config_setting_get_float(const config_setting_t *setting)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_set_float(config_setting_t *setting,
-                                           double value)
+int config_setting_set_float(config_setting_t *setting, double value)
 {
   switch(setting->type)
   {
@@ -678,14 +677,14 @@ LIBCONFIG_API int config_setting_set_float(config_setting_t *setting,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_get_bool(const config_setting_t *setting)
+int config_setting_get_bool(const config_setting_t *setting)
 {
   return((setting->type == CONFIG_TYPE_BOOL) ? setting->value.bval : 0);
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_set_bool(config_setting_t *setting, int value)
+int config_setting_set_bool(config_setting_t *setting, int value)
 {
   if(setting->type == CONFIG_TYPE_NONE)
     setting->type = CONFIG_TYPE_BOOL;
@@ -698,16 +697,14 @@ LIBCONFIG_API int config_setting_set_bool(config_setting_t *setting, int value)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API const char *config_setting_get_string(
-  const config_setting_t *setting)
+const char *config_setting_get_string(const config_setting_t *setting)
 {
   return((setting->type == CONFIG_TYPE_STRING) ? setting->value.sval : NULL);
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_set_string(config_setting_t *setting,
-                                            const char *value)
+int config_setting_set_string(config_setting_t *setting, const char *value)
 {
   if(setting->type == CONFIG_TYPE_NONE)
     setting->type = CONFIG_TYPE_STRING;
@@ -723,8 +720,7 @@ LIBCONFIG_API int config_setting_set_string(config_setting_t *setting,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_set_format(config_setting_t *setting,
-                                            short format)
+int config_setting_set_format(config_setting_t *setting, short format)
 {
   if((setting->type != CONFIG_TYPE_INT)
      || ((format != CONFIG_FORMAT_DEFAULT) && (format != CONFIG_FORMAT_HEX)))
@@ -737,15 +733,14 @@ LIBCONFIG_API int config_setting_set_format(config_setting_t *setting,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API short config_setting_get_format(config_setting_t *setting)
+short config_setting_get_format(config_setting_t *setting)
 {
   return(setting->format);
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_lookup(const config_t *config,
-                                              const char *path)
+config_setting_t *config_lookup(const config_t *config, const char *path)
 {
   const char *p = path;
   config_setting_t *setting = config->root, *found;
@@ -774,8 +769,7 @@ LIBCONFIG_API config_setting_t *config_lookup(const config_t *config,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API const char *config_lookup_string(const config_t *config,
-                                               const char *path)
+const char *config_lookup_string(const config_t *config, const char *path)
 {
   const config_setting_t *s = config_lookup(config, path);
   if(! s)
@@ -786,7 +780,7 @@ LIBCONFIG_API const char *config_lookup_string(const config_t *config,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API long config_lookup_int(const config_t *config, const char *path)
+long config_lookup_int(const config_t *config, const char *path)
 {
   const config_setting_t *s = config_lookup(config, path);
   if(! s)
@@ -797,8 +791,7 @@ LIBCONFIG_API long config_lookup_int(const config_t *config, const char *path)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API double config_lookup_float(const config_t *config,
-                                         const char *path)
+double config_lookup_float(const config_t *config, const char *path)
 {
   const config_setting_t *s = config_lookup(config, path);
   if(! s)
@@ -809,7 +802,7 @@ LIBCONFIG_API double config_lookup_float(const config_t *config,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_lookup_bool(const config_t *config, const char *path)
+int config_lookup_bool(const config_t *config, const char *path)
 {
   const config_setting_t *s = config_lookup(config, path);
   if(! s)
@@ -820,8 +813,7 @@ LIBCONFIG_API int config_lookup_bool(const config_t *config, const char *path)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API long config_setting_get_int_elem(const config_setting_t *vector,
-                                               int index)
+long config_setting_get_int_elem(const config_setting_t *vector, int index)
 {
   const config_setting_t *element = config_setting_get_elem(vector, index);
 
@@ -830,8 +822,8 @@ LIBCONFIG_API long config_setting_get_int_elem(const config_setting_t *vector,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_set_int_elem(
-  config_setting_t *vector, int index, long value)
+config_setting_t *config_setting_set_int_elem(config_setting_t *vector,
+                                              int index, long value)
 {
   config_setting_t *element = NULL;
 
@@ -861,8 +853,7 @@ LIBCONFIG_API config_setting_t *config_setting_set_int_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API double config_setting_get_float_elem(
-  const config_setting_t *vector, int index)
+double config_setting_get_float_elem(const config_setting_t *vector, int index)
 {
   config_setting_t *element = config_setting_get_elem(vector, index);
 
@@ -871,8 +862,8 @@ LIBCONFIG_API double config_setting_get_float_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_set_float_elem(
-  config_setting_t *vector, int index, double value)
+config_setting_t *config_setting_set_float_elem(config_setting_t *vector,
+                                                int index, double value)
 {
   config_setting_t *element = NULL;
 
@@ -900,8 +891,7 @@ LIBCONFIG_API config_setting_t *config_setting_set_float_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_get_bool_elem(const config_setting_t *vector,
-                                               int index)
+int config_setting_get_bool_elem(const config_setting_t *vector, int index)
 {
   config_setting_t *element = config_setting_get_elem(vector, index);
 
@@ -916,8 +906,8 @@ LIBCONFIG_API int config_setting_get_bool_elem(const config_setting_t *vector,
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_set_bool_elem(
-  config_setting_t *vector, int index, int value)
+config_setting_t *config_setting_set_bool_elem(config_setting_t *vector,
+                                               int index, int value)
 {
   config_setting_t *element = NULL;
 
@@ -945,8 +935,8 @@ LIBCONFIG_API config_setting_t *config_setting_set_bool_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API const char *config_setting_get_string_elem(
-  const config_setting_t *vector, int index)
+const char *config_setting_get_string_elem(const config_setting_t *vector,
+                                           int index)
 {
   config_setting_t *element = config_setting_get_elem(vector, index);
 
@@ -961,8 +951,8 @@ LIBCONFIG_API const char *config_setting_get_string_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_set_string_elem(
-  config_setting_t *vector, int index, const char *value)
+config_setting_t *config_setting_set_string_elem(config_setting_t *vector,
+                                                 int index, const char *value)
 {
   config_setting_t *element = NULL;
 
@@ -990,8 +980,8 @@ LIBCONFIG_API config_setting_t *config_setting_set_string_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_get_elem(
-  const config_setting_t *vector, unsigned int index)
+config_setting_t *config_setting_get_elem(const config_setting_t *vector,
+                                          unsigned int index)
 {
   config_list_t *list = vector->value.list;
   
@@ -1008,8 +998,8 @@ LIBCONFIG_API config_setting_t *config_setting_get_elem(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_get_member(
-  const config_setting_t *setting, const char *name)
+config_setting_t *config_setting_get_member(const config_setting_t *setting,
+                                            const char *name)
 {
   if(setting->type != CONFIG_TYPE_GROUP)
     return(NULL);
@@ -1019,15 +1009,14 @@ LIBCONFIG_API config_setting_t *config_setting_get_member(
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API void config_set_destructor(config_t *config,
-                                         void (*destructor)(void *))
+void config_set_destructor(config_t *config, void (*destructor)(void *))
 {
   config->destructor = destructor;
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_length(const config_setting_t *setting)
+int config_setting_length(const config_setting_t *setting)
 {
   if((setting->type != CONFIG_TYPE_GROUP)
      && (setting->type != CONFIG_TYPE_ARRAY)
@@ -1042,16 +1031,15 @@ LIBCONFIG_API int config_setting_length(const config_setting_t *setting)
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API void config_setting_set_hook(config_setting_t *setting,
-                                           void *hook)
+void config_setting_set_hook(config_setting_t *setting, void *hook)
 {
   setting->hook = hook;
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API config_setting_t *config_setting_add(config_setting_t *parent,
-                                                   const char *name, int type)
+config_setting_t *config_setting_add(config_setting_t *parent, const char *name,
+                                     int type)
 {
   if((type < CONFIG_TYPE_NONE) || (type > CONFIG_TYPE_LIST))
     return(NULL);
@@ -1064,15 +1052,14 @@ LIBCONFIG_API config_setting_t *config_setting_add(config_setting_t *parent,
 
   if(name)
     if(config_setting_get_member(parent, name) != NULL)
-      return(NULL); // already exists
+      return(NULL); /* already exists */
 
   return(config_setting_create(parent, name, type));
 }
 
 // ---------------------------------------------------------------------------
 
-LIBCONFIG_API int config_setting_remove(config_setting_t *parent,
-                                        const char *name)
+int config_setting_remove(config_setting_t *parent, const char *name)
 {
   unsigned int index;
   config_setting_t *setting;
